import uuid

from gcs_cli.helpers import requires_login
from gcs_cli.parsing import collection_id_arg, globus_command
from gcs_cli.prettyprint import FORMAT_TEXT_RECORD, formatted_print
from gcs_cli.services.gcs import get_client

FIELDS = [
    ("Domain Name", "domain_name"),
    ("Wildcard", "wildcard"),
    ("Certificate", "certificate"),
    ("Certificate Path", "certificate_path"),
    ("Chain Path", "certificate_chain_path"),
    ("Private Key Path", "private_key_path"),
]


@globus_command(
    "show",
    short_help="Get information about a collection's custom domain",
)
@collection_id_arg
@requires_login
def domain_show(collection_id: uuid.UUID) -> None:
    """
    Get the custom domain being used by this collection.
    """
    client = get_client()

    res = client.get_collection_domain(collection_id)
    fields = []
    for name, key in FIELDS:
        if key in res:
            fields.append((name, key))

    formatted_print(res, text_format=FORMAT_TEXT_RECORD, fields=fields)
