import uuid

from gcs_cli.helpers import record_print_result_message, requires_login
from gcs_cli.parsing import collection_id_arg, globus_command
from gcs_cli.services.gcs import get_client


@globus_command(
    "reset-owner-string",
    short_help="Reset the advertised owner string for a collection",
)
@collection_id_arg
@requires_login
def collection_reset_owner_string(collection_id: uuid.UUID) -> None:
    """
    Reset the advertised owner string for the given collection to the default.

    This command may only be performed by an collection administrator, endpoint
    owner or endpoint administrator. If successful, it resets the collection's
    advertised owner string to the endpoint's client_id.
    """
    client = get_client()

    res = client.delete_collection_owner_string(collection_id)
    record_print_result_message(res)
