import uuid
from typing import Optional

import click

from globus_sdk.paging import Paginator

from gcs_cli.helpers import default_principal_resolver, requires_login
from gcs_cli.parsing import collection_id_arg, globus_command
from gcs_cli.prettyprint import FORMAT_TEXT_TABLE, FieldSpec, formatted_print
from gcs_cli.services.gcs import get_client

FIELDS: FieldSpec = [
    ("Role ID", "id"),
    ("Collection ID", "collection"),
    ("Role", "role"),
    ("Principal", default_principal_resolver.field),
]


@globus_command("list", short_help="List Roles on a Collection.")
@collection_id_arg
@click.option("--my-roles", is_flag=True, help="Only list roles which apply to you")
@requires_login
def role_list(collection_id: uuid.UUID, my_roles: bool = False) -> None:
    """
    List Roles on a Collection.
    """
    include: Optional[str] = None
    if not my_roles:
        include = "all_roles"

    client = get_client()
    res: Paginator = client.paginated.get_role_list(
        collection_id=collection_id, include=include
    )

    formatted_print(
        res,
        text_format=FORMAT_TEXT_TABLE,
        fields=FIELDS,
        page_callback=default_principal_resolver.page_callback,
    )
