from typing import Any, Iterable, Optional

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    ceph_options,
    globus_command,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import CephStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import CEPH_CONNECTOR_ID


@globus_command("ceph")
@storage_gateway_create_and_update_params(create=True)
@ceph_options
@make_create_command
def ceph_create(
    *,
    s3_endpoint: Optional[str],
    bucket: Optional[Iterable[str]],
    ceph_admin_key_id: Optional[str],
    ceph_admin_secret_key: Optional[str],
    **kwargs: Any
) -> StorageGatewayDocument:
    """Create a new Ceph Storage Gateway"""
    policies = CephStoragePolicies(
        s3_endpoint=s3_endpoint,
        s3_buckets=bucket,
        ceph_admin_key_id=ceph_admin_key_id,
        ceph_admin_secret_key=ceph_admin_secret_key,
    )
    return StorageGatewayDocument(
        connector_id=CEPH_CONNECTOR_ID, policies=policies, **kwargs
    )
