from typing import Any, Optional, Union

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    globus_command,
    onedrive_options,
    storage_gateway_create_and_update_params,
)
from gcs_cli.parsing.types import _ExplicitNullClass
from gcs_cli.sdk_client.data import OneDriveStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import ONEDRIVE_CONNECTOR_ID


@globus_command("onedrive")
@storage_gateway_create_and_update_params(create=True)
@onedrive_options
@make_create_command
def onedrive_create(
    *,
    ms_client_id: Optional[str],
    ms_client_secret: Optional[str],
    ms_tenant: Optional[Union[str, _ExplicitNullClass]],
    ms_user_api_rate_limit: Optional[int],
    **kwargs: Any
) -> StorageGatewayDocument:
    """Create a new OneDrive Storage Gateway"""
    policies = OneDriveStoragePolicies(
        client_id=ms_client_id,
        secret=ms_client_secret,
        tenant=ms_tenant,
        user_api_rate_limit=ms_user_api_rate_limit,
    )
    return StorageGatewayDocument(
        connector_id=ONEDRIVE_CONNECTOR_ID, policies=policies, **kwargs
    )
