from typing import Any, Iterable, Optional

from gcs_cli.commands.storage_gateway._common import make_create_command
from gcs_cli.parsing import (
    globus_command,
    s3_options,
    storage_gateway_create_and_update_params,
)
from gcs_cli.sdk_client.data import S3StoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import S3_CONNECTOR_ID


@globus_command("s3", short_help="Create a new S3 Storage Gateway")
@storage_gateway_create_and_update_params(create=True)
@s3_options
@make_create_command
def s3_create(
    *,
    s3_endpoint: Optional[str],
    bucket: Optional[Iterable[str]],
    s3_user_credential: Optional[bool],
    s3_requester_pays: Optional[bool],
    **kwargs: Any,
) -> StorageGatewayDocument:
    """Create a new S3 Storage Gateway"""
    policies = S3StoragePolicies(
        s3_endpoint=s3_endpoint,
        s3_buckets=bucket,
        s3_user_credential_required=s3_user_credential,
        s3_requester_pays=s3_requester_pays,
    )
    return StorageGatewayDocument(
        connector_id=S3_CONNECTOR_ID, policies=policies, **kwargs
    )
