import uuid
from typing import Any, Optional, Tuple

from gcs_cli.commands.storage_gateway._common import make_update_command
from gcs_cli.parsing import (
    blackpearl_options,
    globus_command,
    storage_gateway_create_and_update_params,
    storage_gateway_id_arg,
)
from gcs_cli.sdk_client.data import BlackPearlStoragePolicies, StorageGatewayDocument
from gcs_cli.services.gcs import BLACKPEARL_CONNECTOR_ID


@globus_command("blackpearl", short_help="Update a BlackPearl Storage Gateway")
@storage_gateway_id_arg
@storage_gateway_create_and_update_params(create=False)
@blackpearl_options
@make_update_command
def blackpearl_update(
    storage_gateway_id: uuid.UUID,
    *,
    s3_endpoint: Optional[str],
    blackpearl_access_id_file: Optional[str],
    **kwargs: Any
) -> Tuple[uuid.UUID, StorageGatewayDocument]:
    """
    Update an existing BlackPearl Storage Gateway.
    Any options given will replace existing values in the storage gateway's definition.
    Any options not given will retain their existing values.
    """
    policies = None
    if s3_endpoint is not None or blackpearl_access_id_file is not None:
        policies = BlackPearlStoragePolicies(
            s3_endpoint=s3_endpoint, bp_access_id_file=blackpearl_access_id_file
        )

    return (
        storage_gateway_id,
        StorageGatewayDocument(
            connector_id=BLACKPEARL_CONNECTOR_ID, policies=policies, **kwargs
        ),
    )
