# flake8: noqa
"""


The Globus Connect Server Manager API provides interfaces for
configuring a GCS endpoint and managing storage gateways, user
credentials, and collections.

The GCS API follows the REST design model, with resources representing
storage gateways and their policies, user credentials, and collections.

All operations return a variation of the Result data type, defines
the base message and response code, extended with
operation-specific response data.

## Changes

### 1.0.0
* GCS 5.4.0 release

### 1.1.0
* GCS 5.4.5 release
* Add `enable_https`, `user_message`, and `user_message_link` to
  Collection document (`collection#1.1.0`)

### 1.2.0
* GCS 5.4.8 release
* Add `sharing_users_allow`, `sharing_users_deny` to the
  Collection document (`collection#1.2.0`)
* Add `sharing_groups_allow`, `sharing_groups_deny` to the
  Posix Collection Policies document (`posix_collection_policies#1.1.0`)

### 1.3.0
* GCS 5.4.10 release
* Add POSIX staging connector and related policy documents.
* Add iRODS connector and related policy documents

### 1.4.0
* GCS 5.4.13 release
* Add custom domain APIs: the `/endpoint/domain` and
  `/collections/{collection_id}/domain` route and the
  `custom_domain#1.0.0` document.

### 1.5.0
* GCS 5.4.15 release
* Add node#1.1.0 document

### 1.6.0
* GCS 5.4.18 release
* Add OneDrive connector and related policy documents
* Replace google-cloud-platform-connector module with
  a more correct oauth-credential-api module.
* Add support for user sharing policies

### 1.7.0
* GCS 5.4.21 release
* Added support for the multi-factor requirement to storage gateways
* Added force_verify to collection#1.4.0
* Add ActiveScale connector

### 1.8.0
* GCS 5.4.27 release
* Added disable_anonymous_writes to collection#1.5.0

### 1.9.0
* GCS 5.4.28 release
* Add Azure Blob storage support

### 1.10.0
* GCS 5.4.30 release
* Add service_account_key to google_cloud_storage_policies#1.0.0

### 1.11.0
* GCS 5.4.43 release
* Add API routes for endpoint and collection advertised
  owner_string.
* Add HPSS connector

### 1.12.0
* GCS 5.4.49 release
* Add admin_managed_credentials property to storage_gateway#1.2.0

### 1.13.0
* GCS 5.4.51 release
* Add include=all optional query parameter to GET /user_credentials.

### 1.14.0
* GCS 5.4.55 release
* Add endpoint#1.1.0 document type to support setting GridFTP
  control port to something other than 443

### 1.15.0
* GCS 5.4.57 release
* Add guest_auth_policy_id for collections
* Increase maxLength of user_message to 256
* Clarify visibility of root_path on guest collections
* Add delete_protected for collections

### 1.16.0
* GCS 5.4.58 release
* Allow users with an administrator role on a mapped collection to
  delete guest collections associated with that collection.
* GET /storage_gateways no longer quietly ignores private_policies

### 1.17.0
* GCS 5.4.59 release
* Add s3_requester_pays support to the S3 connector.

### 1.18.0
* GCS 5.4.60 release
* Add the read-only created_at and last_access properties to the
  collection schema.
* Add new filter query parameter value to GET /api/collections to allow
  filtering collections by created_at or last_access property values.
* Add new API for deleting multiple guest collections in one request.

## API Reference

"""

from .account import account_schema
from .batch import batch_schema
from .authentication_timeout import authentication_timeout_schema
from .collection import (
    collection_schema,
    collection_patch_schema,
    collection_private_schema,
    collection_configuration_schema,
)
from .connector import connector_schema
from .credential_not_found import credential_not_found_schema
from .data_type import data_type_schema
from .domain import (
    DomainDict,
    ManagedDomainDict,
    UnmanagedDomainDict,
    domain_schema,
)
from .endpoint import endpoint_schema, endpoint_patch_schema
from .endpoint_owner import endpoint_owner_schema
from .endpoint_subscription import endpoint_subscription_schema
from .id_not_in_identity_set import id_not_in_identity_set_schema
from .info import info_schema
from .invalid_credential import invalid_credential_schema
from .invalid_input import invalid_input_schema
from .invalid_user import invalid_user_schema
from .identity_mapping import identity_mapping_schema
from .limit_exceeded import limit_exceeded_schema
from .missing_required_role import missing_required_role_schema
from .missing_required_scopes import missing_required_scopes_schema
from .node import node_schema, node_patch_schema
from .not_from_allowed_domain import not_from_allowed_domain_schema
from .not_resource_owner import not_resource_owner_schema
from .owner_string import owner_string_schema
from .path_restrictions import path_restrictions_schema, PathRestrictionsDict
from .result import result_schema
from .resource_conflict import resource_conflict_schema
from .role import role_schema
from .sharing_policy import (
    SharingPolicyDumpDict,
    SharingPolicyLoadDict,
    sharing_policy_schema,
)
from .semantic_version import semantic_version_expression
from .storage_gateway import (
    storage_gateway_schema,
    storage_gateway_private_schema,
)
from .subscription_required import subscription_required_schema
from .user_credential import (
    user_credential_schema,
    user_credential_patch_schema,
    user_credential_private_schema,
)
