import marshmallow as ma
from .data_type import DataTypeField, DataTypeSchema


class AuthenticationTimeout(ma.Schema):
    """
    Error details when a user must reauthenticate an identity
    in order to perform this operation.
    """

    _DATA_TYPE = "authentication_timeout#1.1.0"
    DATA_TYPE = DataTypeField(_DATA_TYPE)
    identities = ma.fields.List(
        ma.fields.UUID,
        description="""
        List of identities that would have otherwise been
        authorized except that the authentication has timed out.
        """,
    )
    high_assurance = ma.fields.Boolean(
        description="""
        Boolean flag indicating whether the new authentication
        must be done within the same auth session as the
        application making the request.
        """,
    )
    require_mfa = ma.fields.Boolean(
        description="""
        Flag indicating that multi-factor authentication is required.
        Only occurs on high assurance storage gateways.
        """
    )


authentication_timeout_schema = AuthenticationTimeout()
DataTypeSchema.register_schema(authentication_timeout_schema)
