import marshmallow as ma

from .data_type import DataTypeField, DataTypeSchema
from .account import account_schema


class CredentialNotFound(ma.Schema):
    """
    Error details when a user has attempted to use a credential when creating a
    collection or logging in, but there are multiple mapped identities and none
    of them have a valid credential.
    """

    _DATA_TYPE = "credential_not_found#1.0.0"
    DATA_TYPE = DataTypeField(_DATA_TYPE)
    accounts = ma.fields.List(
        ma.fields.Nested(account_schema),
        required=True,
        description="""
        List of available accounts that do not have credentials registered.
        """,
    )


credential_not_found_schema = CredentialNotFound()
DataTypeSchema.register_schema(credential_not_found_schema)
