import marshmallow as ma

from .data_type import DataTypeField, DataTypeSchema


class InvalidInputItem(ma.Schema):
    message = ma.fields.String(
        required=True,
        allow_none=False,
        description="Error message describing the invalid input error",
    )

    _property = ma.fields.String(
        data_key="property",
        attribute="property",
        required=False,
        allow_none=False,
        description="""
        Name of the property whose value contains the error, if known. May
        be unset depending on the error.
        """,
    )


class InvalidInput(ma.Schema):
    """
    Error details when the caller has sent an invalid input document.
    """

    _DATA_TYPE = "invalid_input#1.0.0"
    DATA_TYPE = DataTypeField(_DATA_TYPE)
    errors = ma.fields.List(
        ma.fields.Nested(InvalidInputItem),
        description="""
        Optional list of input schema violations, such as missing or
        unknown properties, or properties with invalid values.
        """,
    )


invalid_input_schema = InvalidInput()
DataTypeSchema.register_schema(invalid_input_schema)
