import marshmallow as ma
from .data_type import DataTypeField, DataTypeSchema


class MissingRoleEntrySchema(ma.Schema):
    role = ma.fields.String(
        required=True,
        validate=[
            ma.validate.OneOf(
                [
                    "owner",
                    "administrator",
                    "access_manager",
                    "activity_manager",
                    "activity_monitor",
                    "access_monitor",
                ]
            )
        ],
    )
    collection = ma.fields.UUID(
        description="""
        The collection which the role must apply to. If omitted, the role
        must apoly to an endpoint.
        """
    )


class MissingRequiredRole(ma.Schema):
    """
    Error details when a user has authenticated but lacks a role to be able to
    perform the requested operation.
    """

    _DATA_TYPE = "missing_required_role#1.0.0"
    DATA_TYPE = DataTypeField(_DATA_TYPE)
    roles = ma.fields.List(
        ma.fields.Nested(MissingRoleEntrySchema),
        description="List of roles authorized to perform this operation",
    )


missing_required_role_schema = MissingRequiredRole()
DataTypeSchema.register_schema(missing_required_role_schema)
