import uuid
import typing as t

import click

from gcs_cli.parsing.command_decorator import globus_command

from globus.manager.utils.keychain import NodeKey
from .utils.key_and_credentials import key_and_credentials_options


@globus_command(
    "cleanup",
    short_help="Clean up a Globus Connect Server endpoint",
    help="Clean up a Globus Connect Server endpoint",
    disable_options=["format", "explicit_host"],
)
@key_and_credentials_options(
    id_required=True,
    secret_required=True,
    key_exists=False,  # Key is not required, admin may have lost it
    key_writable=False,
)
@click.option(
    "--development-appsync",
    help="Use the specified URL and client_id for the appsync service",
    metavar="APPSYNC_URL APPSYNC_CLIENT_ID",
    nargs=2,
    hidden=True,
)
@click.pass_context
def endpoint_cleanup(
    ctx: click.Context,
    client_id: uuid.UUID,
    secret: str,
    deployment_key_path: str,
    deployment_key: NodeKey,
    development_appsync: t.Optional[t.Tuple[str, str]],
):
    from .endpoint_cleanup import endpoint_cleanup as ec

    ec(
        ctx,
        str(client_id),
        secret,
        deployment_key_path,
        deployment_key,
        development_appsync,
    )
