from typing import Tuple, TypeVar, Union
import click
import re
from globus.manager.constants import HOSTNAME_PATTERN, DOMAIN_NAME_PATTERN


def verify_hostname_option(
    ctx: click.Context, param: Union[click.Option, click.Parameter], value: str
) -> str:
    if value and not re.match(HOSTNAME_PATTERN, value):
        raise click.BadParameter("Invalid hostname: " + value)
    return value


StringOrStringTuple = TypeVar("StringOrStringTuple", str, Tuple[str])


def verify_domain_name_option(
    ctx: click.Context,
    param: Union[click.Option, click.Parameter],
    value: StringOrStringTuple,
) -> StringOrStringTuple:
    if isinstance(value, tuple):
        for v in value:
            if not re.match(DOMAIN_NAME_PATTERN, v):
                raise click.BadParameter("Invalid domain name: " + v)
            elif v and len(v) > 253:
                raise click.BadParameter("Invalid domain name: " + v)
    elif value and ((not re.match(DOMAIN_NAME_PATTERN, value)) or (len(value) > 253)):
        raise click.BadParameter("Invalid domain name: " + value)
    return value
